<!-- omit in toc -->
# ✨ MiniMCP Servers

![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)
![Python](https://img.shields.io/badge/python-3.10%2B-blue)
[![PyPI version](https://img.shields.io/pypi/v/minimcp-servers.svg)](https://pypi.org/project/minimcp-servers/)

MCP servers built with MiniMCP to expose Python’s standard library modules.
